Crate midi_toolkit

Crate midi_toolkit 

Modules

events
io
notes
num
prelude
sequence

Macros

gen_iter
macro to simplify iterator - via - coroutine construction
gen_iter_return
macro to simplify iterator - via - coroutine with return value construction
pipeDeprecated
unwrap
yield_error

Structs

DelayedReceiver
GenIter
an iterator that holds an internal coroutine representing the iteration state
GenIterReturn
GenIterReturn<G> holds a coroutine G or the return value of G, &mut GenIterReturn<G> acts as an iterator.